conversion

package
v0.0.0-...-d01e91e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 31, 2023 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CalcRelativeHumidity

func CalcRelativeHumidity(temp, dewpoint int) int

CalcRelativeHumidity - calculates the relative humidity of the dew point and temperature

func DirectionToCardinalDirection

func DirectionToCardinalDirection(dir int) string

DirectionToCardinalDirection - converts direction in degrees to points of the compass

func FtToM

func FtToM(ft int) int

FtToM - converts feet to meters (rounded to 10 meters)

func FtToSMile

func FtToSMile(m int) float64

FtToSMile - converts feet to statute miles

func HPaToMmHg

func HPaToMmHg(hPa int) int

HPaToMmHg - converts hectopascal to mm of mercury

func InHgTohPa

func InHgTohPa(inHg float64) int

InHgTohPa - converts inch of mercury to hectopascal

func KphToKts

func KphToKts(kph int) float64

KphToKts - converts kilometres per hour to knots

func KphToMps

func KphToMps(kph int) float64

KphToMps - converts kilometres per hour to meters per second

func KtsToMps

func KtsToMps(kts float64) float64

KtsToMps - converts knots to meters per second

func MToFt

func MToFt(m int) int

MToFt - converts metres to feet (rounded to 10)

func MToSMile

func MToSMile(m int) float64

MToSMile - converts metres to statute miles

func MmHgToHPa

func MmHgToHPa(mm int) int

MmHgToHPa - converts mm of mercury to hectopascal

func MpsToKts

func MpsToKts(m float64) float64

MpsToKts - converts meters per second to knots

func SMileToFt

func SMileToFt(m float64) int

SMileToFt - converts statute miles to feet

func SMileToM

func SMileToM(sm float64) int

SMileToM - converts statute miles to meters

Types

This section is empty.

Jump to