Documentation
¶
Index ¶
- func CalcRelativeHumidity(temp, dewpoint int) int
- func DirectionToCardinalDirection(dir int) string
- func FtToM(ft int) int
- func FtToSMile(m int) float64
- func HPaToMmHg(hPa int) int
- func InHgTohPa(inHg float64) int
- func KphToKts(kph int) float64
- func KphToMps(kph int) float64
- func KtsToMps(kts float64) float64
- func MToFt(m int) int
- func MToSMile(m int) float64
- func MmHgToHPa(mm int) int
- func MpsToKts(m float64) float64
- func SMileToFt(m float64) int
- func SMileToM(sm float64) int
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CalcRelativeHumidity ¶
CalcRelativeHumidity - calculates the relative humidity of the dew point and temperature
func DirectionToCardinalDirection ¶
DirectionToCardinalDirection - converts direction in degrees to points of the compass
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.